---
title: "Tutte's Embedding"
---

Usage:
```python
import mouette as M
from mouette.processing import parametrization

tutte = TutteEmbedding(mesh, [options])()
```
or, alternatively:
```
tutte = TutteEmbedding(mesh, [options])
tutte.run()
```

:::mouette.processing.parametrization.tutte.TutteEmbedding